# topiary

Python framework for doing ancestral sequence reconstruction using pandas dataframes and ete3 trees as the primary data structures.

*Under heavy development.*

[Documentation](https://topiary-asr.readthedocs.io/en/latest/)

